Index: Source/modules/crypto/NormalizeAlgorithm.h |
diff --git a/Source/modules/crypto/NormalizeAlgorithm.h b/Source/modules/crypto/NormalizeAlgorithm.h |
index fdf1fd6299518a912e111769984786d87c8ebef5..adef2e6e8aad06652749a9ccd7ddaf224681daf4 100644 |
--- a/Source/modules/crypto/NormalizeAlgorithm.h |
+++ b/Source/modules/crypto/NormalizeAlgorithm.h |
@@ -56,8 +56,9 @@ enum AlgorithmOperation { |
}; |
// Normalizes an algorithm identifier (dictionary) into a WebCryptoAlgorithm. If |
// normalization fails then returns false and sets |ec|. |
bool normalizeAlgorithm(const Dictionary&, AlgorithmOperation, WebKit::WebCryptoAlgorithm&, ExceptionCode&) WARN_UNUSED_RETURN; |
+bool normalizeAlgorithmForImportKey(const Dictionary&, WebKit::WebCryptoAlgorithm&, ExceptionCode&) WARN_UNUSED_RETURN; |
} // namespace WebCore |
@@ -56,8 +56,9 @@ enum AlgorithmOperation { |
}; |
// Normalizes an algorithm identifier (dictionary) into a WebCryptoAlgorithm. If |
-// normalization fails then returns false and sets |ec|. |
+// normalization fails then returns false and sets the ExceptionCode. |
bool normalizeAlgorithm(const Dictionary&, AlgorithmOperation, WebKit::WebCryptoAlgorithm&, ExceptionCode&) WARN_UNUSED_RETURN; |